@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 '''Main tldextract unit tests.'''
 
-import sys
+import logging
+import os
+import tempfile
 
 import pytest
 import responses
@@ -9,19 +11,16 @@ import tldextract
 from tldextract.cache import DiskCache
 from tldextract.suffix_list import SuffixListNotFound
 from tldextract.tldextract import ExtractResult
-from .helpers import temporary_dir
 
 
-# pylint: disable=invalid-name
-extract = tldextract.TLDExtract(cache_dir=temporary_dir())
+extract = tldextract.TLDExtract(cache_dir=tempfile.mkdtemp())
 extract_no_cache = tldextract.TLDExtract(cache_dir=False)
-extract_using_real_local_suffix_list = tldextract.TLDExtract(cache_dir=temporary_dir())
+extract_using_real_local_suffix_list = tldextract.TLDExtract(cache_dir=tempfile.mkdtemp())
 extract_using_real_local_suffix_list_no_cache = tldextract.TLDExtract(cache_dir=False)
 extract_using_fallback_to_snapshot_no_cache = tldextract.TLDExtract(
     cache_dir=None,
     suffix_list_urls=None
 )
-# pylint: enable=invalid-name
 
 
 def assert_extract(  # pylint: disable=missing-docstring
@@ -237,11 +236,36 @@ def test_result_as_dict():
     assert result._asdict() == expected_dict
 
 
-@responses.activate  # pylint: disable=no-member
+def test_cache_permission(mocker, monkeypatch, tmpdir):
+    """Emit a warning once that this can't cache the latest PSL."""
+
+    warning = mocker.patch.object(logging.getLogger("tldextract.cache"), "warning")
+
+    def no_permission_makedirs(*args, **kwargs):
+        raise PermissionError(
+            """[Errno 13] Permission denied:
+            '/usr/local/lib/python3.7/site-packages/tldextract/.suffix_cache"""
+        )
+
+    monkeypatch.setattr(os, "makedirs", no_permission_makedirs)
+
+    for _ in range(0, 2):
+        my_extract = tldextract.TLDExtract(cache_dir=tmpdir)
+        assert_extract(
+            "http://www.google.com",
+            ("www.google.com", "www", "google", "com"),
+            funs=(my_extract,),
+        )
+
+    assert warning.call_count == 1
+    assert warning.call_args[0][0].startswith("unable to cache")
+
+
+@responses.activate
 def test_cache_timeouts(tmpdir):
     server = 'http://some-server.com'
-    responses.add(  # pylint: disable=no-member
-        responses.GET,  # pylint: disable=no-member
+    responses.add(
+        responses.GET,
         server,
         status=408
     )
@@ -266,6 +290,8 @@ def test_tlds_property():
 
 
 def test_global_extract():
-    assert tldextract.extract("foo.blogspot.com") == ExtractResult(subdomain='foo', domain='blogspot', suffix='com')
+    assert tldextract.extract("foo.blogspot.com") == ExtractResult(
+        subdomain="foo", domain="blogspot", suffix="com"
+    )
     assert tldextract.extract("foo.blogspot.com", include_psl_private_domains=True) == \
            ExtractResult(subdomain='', domain='foo', suffix='blogspot.com')
